@@ -1,11 +1,15 @@
 import time
 
-from loguru import logger
+# Импортируем get_logger из utils
+from shadowstep.utils import get_logger
 from selenium.common.exceptions import InvalidSessionIdException, NoSuchDriverException, WebDriverException
 
 from shadowstep.shadowstep import Shadowstep
 from tests.conftest import UDID
 
+# Получаем логгер для текущего модуля
+logger = get_logger(__name__)
+
 caps = {
     "platformName": "android",
     "appium:automationName": "uiautomator2",
